=======
History
=======

unyt began life as a submodule of yt named yt.units.

It was separated from yt.units as its own package in 2018.

0.1.0 (2018-03-28)
------------------

* First release on PyPI.
